@@ -1,25 +1,11 @@
-/*************************************************************************
- * Copyright (C) 2014 by Hugo Pereira Da Costa <hugo.pereira@free.fr>    *
- *                                                                       *
- * This program is free software; you can redistribute it and/or modify  *
- * it under the terms of the GNU General Public License as published by  *
- * the Free Software Foundation; either version 2 of the License, or     *
- * (at your option) any later version.                                   *
- *                                                                       *
- * This program is distributed in the hope that it will be useful,       *
- * but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- * GNU General Public License for more details.                          *
- *                                                                       *
- * You should have received a copy of the GNU General Public License     *
- * along with this program; if not, write to the                         *
- * Free Software Foundation, Inc.,                                       *
- * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
- *************************************************************************/
+/*
+ * SPDX-FileCopyrightText: 2014 Hugo Pereira Da Costa <hugo.pereira@free.fr>
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
 
 #include "breezehelper.h"
 
-#include "breeze.h"
 #include "breezestyleconfigdata.h"
 
 #include <KColorUtils>
@@ -29,7 +15,7 @@
 #include <QApplication>
 #include <QPainter>
 
-#if BREEZE_HAVE_X11
+#if BREEZE_HAVE_QTX11EXTRAS
 #include <QX11Info>
 #endif
 
@@ -56,6 +42,7 @@ namespace Breeze
         _viewFocusBrush = KStatefulBrush( KColorScheme::View, KColorScheme::FocusColor );
         _viewHoverBrush = KStatefulBrush( KColorScheme::View, KColorScheme::HoverColor );
         _viewNegativeTextBrush = KStatefulBrush( KColorScheme::View, KColorScheme::NegativeText );
+        _viewNeutralTextBrush = KStatefulBrush( KColorScheme::View, KColorScheme::NeutralText );
 
         const QPalette palette( QApplication::palette() );
         const KConfigGroup group( _config->group( "WM" ) );
@@ -1576,7 +1563,7 @@ namespace Breeze
     bool Helper::compositingActive() const
     {
 
-        #if BREEZE_HAVE_X11
+        #if BREEZE_HAVE_QTX11EXTRAS
         if( isX11() )
         { return QX11Info::isCompositingManagerRunning( QX11Info::appScreen() ); }
         #endif
