@@ -1,27 +1,14 @@
+/*
+ * SPDX-FileCopyrightText: 2014 Hugo Pereira Da Costa <hugo.pereira@free.fr>
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
 #ifndef breeze_helper_h
 #define breeze_helper_h
 
-/*************************************************************************
- * Copyright (C) 2014 by Hugo Pereira Da Costa <hugo.pereira@free.fr>    *
- *                                                                       *
- * This program is free software; you can redistribute it and/or modify  *
- * it under the terms of the GNU General Public License as published by  *
- * the Free Software Foundation; either version 2 of the License, or     *
- * (at your option) any later version.                                   *
- *                                                                       *
- * This program is distributed in the hope that it will be useful,       *
- * but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- * GNU General Public License for more details.                          *
- *                                                                       *
- * You should have received a copy of the GNU General Public License     *
- * along with this program; if not, write to the                         *
- * Free Software Foundation, Inc.,                                       *
- * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
- *************************************************************************/
-
-
 #include "breeze.h"
+#include "breezemetrics.h"
 #include "breezeanimationdata.h"
 #include "config-breeze.h"
 
@@ -72,6 +59,10 @@ namespace Breeze
         QColor negativeText( const QPalette& palette ) const
         { return _viewNegativeTextBrush.brush( palette ).color(); }
 
+        //* neutral text color
+        QColor neutralText( const QPalette& palette ) const
+        { return _viewNeutralTextBrush.brush( palette ).color(); }
+
         //* shadow
         QColor shadowColor( const QPalette& palette ) const
         { return alphaColor( palette.color( QPalette::Shadow ), 0.15 ); }
@@ -301,6 +292,7 @@ namespace Breeze
         KStatefulBrush _viewFocusBrush;
         KStatefulBrush _viewHoverBrush;
         KStatefulBrush _viewNegativeTextBrush;
+        KStatefulBrush _viewNeutralTextBrush;
         //@}
 
         //*@name windeco colors
