@@ -1,26 +1,13 @@
-/*************************************************************************
- * Copyright (C) 2014 by Hugo Pereira Da Costa <hugo.pereira@free.fr>    *
- * Copyright (C) 2018, 2020 by Vlad Zahorodnii <vlad.zahorodnii@kde.org> *
- *                                                                       *
- * This program is free software; you can redistribute it and/or modify  *
- * it under the terms of the GNU General Public License as published by  *
- * the Free Software Foundation; either version 2 of the License, or     *
- * (at your option) any later version.                                   *
- *                                                                       *
- * This program is distributed in the hope that it will be useful,       *
- * but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- * GNU General Public License for more details.                          *
- *                                                                       *
- * You should have received a copy of the GNU General Public License     *
- * along with this program; if not, write to the                         *
- * Free Software Foundation, Inc.,                                       *
- * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
- *************************************************************************/
+/*
+ * SPDX-FileCopyrightText: 2014 Hugo Pereira Da Costa <hugo.pereira@free.fr>
+ * SPDX-FileCopyrightText: 2018, 2020 Vlad Zahorodnii <vlad.zahorodnii@kde.org>
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
 
 #include "breezeshadowhelper.h"
 
-#include "breeze.h"
+#include "breezemetrics.h"
 #include "breezeboxshadowrenderer.h"
 #include "breezehelper.h"
 #include "breezepropertynames.h"
@@ -132,7 +119,7 @@ namespace Breeze
         widget->installEventFilter( this );
 
         // connect destroy signal
-        connect( widget, &QObject::destroyed, this, &ShadowHelper::widgetDeleted );
+        connect( widget, &QObject::destroyed, this, &ShadowHelper::objectDeleted );
 
         return true;
 
@@ -278,17 +265,12 @@ namespace Breeze
 
 
     //_______________________________________________________
-    void ShadowHelper::widgetDeleted( QObject* object )
+    void ShadowHelper::objectDeleted( QObject* object )
     {
         QWidget* widget( static_cast<QWidget*>( object ) );
         _widgets.remove( widget );
-    }
+        _shadows.remove( widget );
 
-    //_______________________________________________________
-    void ShadowHelper::windowDeleted( QObject* object )
-    {
-        QWindow* window( static_cast<QWindow*>( object ) );
-        _shadows.remove( window );
     }
 
     //_______________________________________________________
@@ -386,20 +368,11 @@ namespace Breeze
         const QVector<KWindowShadowTile::Ptr>& tiles = createShadowTiles();
         if( tiles.count() != numTiles ) return;
 
-        // get the underlying window for the widget
-        QWindow* window = widget->windowHandle();
-
         // find a shadow associated with the widget
-        KWindowShadow*& shadow = _shadows[ window ];
+        KWindowShadow*& shadow = _shadows[ widget ];
 
         if( !shadow )
-        {
-            // if there is no shadow yet, create one
-            shadow = new KWindowShadow( window );
-
-            // connect destroy signal
-            connect( window, &QWindow::destroyed, this, &ShadowHelper::windowDeleted );
-        }
+        { shadow = new KWindowShadow( widget ); }
 
         if( shadow->isCreated() )
         { shadow->destroy(); }
@@ -413,7 +386,7 @@ namespace Breeze
         shadow->setLeftTile( tiles[ 6 ] );
         shadow->setTopLeftTile( tiles[ 7 ] );
         shadow->setPadding( shadowMargins( widget ) );
-        shadow->setWindow( window );
+        shadow->setWindow( widget->windowHandle() );
         shadow->create();
     }
 
@@ -467,7 +440,7 @@ namespace Breeze
     //_______________________________________________________
     void ShadowHelper::uninstallShadows( QWidget* widget )
     {
-        delete _shadows.take( widget->windowHandle() );
+        delete _shadows.take( widget );
     }
 
 }
